Contributions are welcome!

- Create an [issue](https://github.com/christianhbye/croissant/issues) if you discover a bug, have a feature request, or a question.
- If you want to fix an issue, clone this repository and install it in developer mode (with `pip install .[dev]`). Then create a [pull request](https://github.com/christianhbye/croissant/pulls) with your changes.

Questions, comments, and suggestions can also be sent to me through email at chbye@berkeley.edu.
